==> glom-0.8.25.tar.bz2: glom-0.8.25/glom/data_structure/layout/layoutitem_portal.cc <==
/* Glom
 *
 * Copyright (C) 2001-2004 Murray Cumming
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
 
#include "layoutitem_portal.h"

LayoutItem_Portal::LayoutItem_Portal()
{
}

LayoutItem_Portal::LayoutItem_Portal(const LayoutItem_Portal& src)
: LayoutItem(src),
  m_relationship(src.m_relationship)
{
}

LayoutItem_Portal::~LayoutItem_Portal()
{
}

LayoutItem* LayoutItem_Portal::clone() const
{
  return new LayoutItem_Portal(*this);
}


LayoutItem_Portal& LayoutItem_Portal::operator=(const LayoutItem_Portal& src)
{
  LayoutItem::operator=(src);

  m_relationship = src.m_relationship;

  return *this;
}


Glib::ustring LayoutItem_Portal::get_relationship() const
{
  return m_relationship.get_name();
}

void LayoutItem_Portal::set_relationship(const Glib::ustring& relationship)
{
  m_relationship.set_name(relationship);
}

==> glom-0.8.34.tar.bz2: glom-0.8.34/glom/data_structure/layout/layoutitem_portal.cc <==
/* Glom
 *
 * Copyright (C) 2001-2004 Murray Cumming
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
 
#include "layoutitem_portal.h"
#include <glibmm/i18n.h>

LayoutItem_Portal::LayoutItem_Portal()
{
}

LayoutItem_Portal::LayoutItem_Portal(const LayoutItem_Portal& src)
: LayoutItem(src),
  m_relationship(src.m_relationship)
{
}

LayoutItem_Portal::~LayoutItem_Portal()
{
}

LayoutItem* LayoutItem_Portal::clone() const
{
  return new LayoutItem_Portal(*this);
}


LayoutItem_Portal& LayoutItem_Portal::operator=(const LayoutItem_Portal& src)
{
  LayoutItem::operator=(src);

  m_relationship = src.m_relationship;

  return *this;
}


Glib::ustring LayoutItem_Portal::get_relationship() const
{
  return m_relationship.get_name();
}

void LayoutItem_Portal::set_relationship(const Glib::ustring& relationship)
{
  m_relationship.set_name(relationship);
}


Glib::ustring LayoutItem_Portal::get_part_type_name() const
{
  return _("Portal");
}
